@@ -90,7 +90,7 @@ class GenericViewTestCase(BaseTestCase):
             self.assertEqual(403, response.status_code)
         
         field1, field2 = obj.field1, obj.field2
-        data = {'field1': "ABC", 'field2': "DEF"}
+        data = {'field1': "ABC", 'field2': "DEF", 'bool_field': True, 'int_field': 2, 'float_field': 3.14}
         response = self.client.post(url, data=data)
         
         if coop_settings.is_perm_middleware_installed():
@@ -104,11 +104,32 @@ class GenericViewTestCase(BaseTestCase):
         self.assertEqual(obj.field1, field1)
         self.assertEqual(obj.field2, field2)
         
+        
     def test_view_object_viewer(self):
         self._log_as_viewer()
         obj = mommy.make(TestClass)
         response = self.client.get(obj.get_absolute_url())
         self.assertEqual(200, response.status_code)
+        soup = BeautifulSoup(response.content)
+        self.assertEqual("ABC", soup.select("#properties")[0].text)
+        
+    def test_view_object_viewer_bool_true(self):
+        self._log_as_viewer()
+        obj = mommy.make(TestClass, bool_field=True)
+        response = self.client.get(obj.get_absolute_url())
+        self.assertEqual(200, response.status_code)
+        soup = BeautifulSoup(response.content)
+        self.assertEqual(1, len(soup.select(".bool_field_is_true")))
+        self.assertEqual(0, len(soup.select(".bool_field_is_false")))
+        
+    def test_view_object_viewer_bool_false(self):
+        self._log_as_viewer()
+        obj = mommy.make(TestClass, bool_field=False)
+        response = self.client.get(obj.get_absolute_url())
+        self.assertEqual(200, response.status_code)
+        soup = BeautifulSoup(response.content)
+        self.assertEqual(0, len(soup.select(".bool_field_is_true")))
+        self.assertEqual(1, len(soup.select(".bool_field_is_false")))
     
     def test_edit_object_viewer(self):
         self._log_as_viewer()
@@ -118,7 +139,7 @@ class GenericViewTestCase(BaseTestCase):
         
         field1, field2 = obj.field1, obj.field2
         
-        data = {'field1': "ABC", 'field2': "DEF"}
+        data = {'field1': "ABC", 'field2': "DEF", 'bool_field': True, 'int_field': 2, 'float_field': 3.14}
         response = self.client.post(obj.get_edit_url(), data=data, follow=True)
         self.assertEqual(403, response.status_code)
         
@@ -138,13 +159,17 @@ class GenericViewTestCase(BaseTestCase):
         response = self.client.get(obj.get_edit_url())
         self.assertEqual(200, response.status_code)
         
-        data = {'field1': "ABC", 'field2': "DEF"}
+        data = {'field1': "ABC", 'field2': "DEF", 'bool_field': True, 'int_field': 2, 'float_field': 3.14}
         response = self.client.post(obj.get_edit_url(), data=data, follow=True)
         self.assertEqual(200, response.status_code)
         
         obj = TestClass.objects.get(id=obj.id)
         self.assertEqual(obj.field1, data["field1"])
         self.assertEqual(obj.field2, data["field2"])
+        self.assertEqual(obj.bool_field, data["bool_field"])
+        self.assertEqual(obj.int_field, data["int_field"])
+        self.assertEqual(obj.float_field, data["float_field"])
+        
         
     def test_edit_object_inactive(self):
         self._log_as_editor()
@@ -155,7 +180,7 @@ class GenericViewTestCase(BaseTestCase):
         response = self.client.get(obj.get_edit_url())
         self.assertEqual(403, response.status_code)
         
-        data = {'field1': "ABC", 'field2': "DEF"}
+        data = {'field1': "ABC", 'field2': "DEF", 'bool_field': True, 'int_field': 2, 'float_field': 3.14}
         response = self.client.post(obj.get_edit_url(), data=data, follow=True)
         self.assertEqual(403, response.status_code)
         
@@ -205,22 +230,24 @@ class FormsetViewTestCase(BaseTestCase):
         self.assertContains(response, obj.field2)
         self.assertContains(response, obj.other_field)
         
-    def test_edit_formset_one_object(self):
-        self._log_as_viewer()
-        
-        obj = mommy.make(TestClass)
-        
-        url = reverse('coop_cms_testapp_formset_edit')
-        
-        response = self.client.get(url)
-        self.assertEqual(200, response.status_code)
-        
-        soup = BeautifulSoup(response.content)
-        self.assertEqual(1, len(soup.select('form')))
-        
-        self.assertContains(response, obj.field1)
-        self.assertContains(response, obj.field2)
-        self.assertContains(response, obj.other_field)
+    #def test_edit_formset_one_object(self):
+    #    self._log_as_viewer()
+    #    
+    #    obj = mommy.make(TestClass)
+    #    
+    #    url = reverse('coop_cms_testapp_formset_edit')
+    #    
+    #    response = self.client.get(url)
+    #    self.assertEqual(200, response.status_code)
+    #    
+    #    soup = BeautifulSoup(response.content)
+    #    self.assertEqual(1, len(soup.select('form')))
+    #    
+    #    print response.content
+    #    
+    #    self.assertContains(response, obj.field1)
+    #    self.assertContains(response, obj.field2)
+    #    self.assertContains(response, obj.other_field)
         
     def test_view_formset_several_object(self):
         self._log_as_viewer()
@@ -269,7 +296,7 @@ class FormsetViewTestCase(BaseTestCase):
         response = self.client.post(url, data=data, follow=True)
         self.assertEqual(404, response.status_code)
         
-    def test_edit_formset_one_object(self):
+    def test_post_edit_formset_one_object(self):
         self._log_as_editor()
         
         obj = mommy.make(TestClass)
@@ -283,6 +310,9 @@ class FormsetViewTestCase(BaseTestCase):
             'form-0-field2': "<p>QWERTY/nUIOP</p>",
             #'form-0-field3': "",
             'form-0-other_field': "wxcvbn",
+            'form-0-bool_field': True,
+            'form-0-int_field': 2,
+            'form-0-float_field': 3.14,
             'form-TOTAL_FORMS': 1,
             'form-INITIAL_FORMS': 1,
             'form-MAX_NUM_FORMS': 1,
@@ -300,6 +330,9 @@ class FormsetViewTestCase(BaseTestCase):
         self.assertEqual(data['form-0-field1'], obj.field1)
         self.assertEqual(data['form-0-field2'], obj.field2)
         self.assertEqual(other_field, obj.other_field)
+        self.assertEqual(data['form-0-bool_field'], obj.bool_field)
+        self.assertEqual(data['form-0-int_field'], obj.int_field)
+        self.assertEqual(data['form-0-float_field'], obj.float_field)
         
         
     def test_edit_formset_several_object(self):
@@ -313,10 +346,16 @@ class FormsetViewTestCase(BaseTestCase):
             'form-0-field1': "AZERTYUIOP",
             'form-0-field2': "<p>QWERTY/nUIOP</p>",
             'form-0-field3': "AZDD",
+            'form-0-bool_field': True,
+            'form-0-int_field': 2,
+            'form-0-float_field': 3.14,
             'form-1-id': obj2.id,
             'form-1-field1': "POIUYTREZA",
             'form-1-field2': "<p>MLKJHGFDSQ</p>",
             'form-1-field3': "QSkk",
+            'form-1-bool_field': False,
+            'form-1-int_field': 2,
+            'form-1-float_field': 3.14,
             'form-TOTAL_FORMS': 2,
             'form-INITIAL_FORMS': 2,
             'form-MAX_NUM_FORMS': 2,
@@ -333,6 +372,9 @@ class FormsetViewTestCase(BaseTestCase):
             self.assertEqual(data['form-{0}-field1'.format(i)], obj.field1)
             self.assertEqual(data['form-{0}-field2'.format(i)], obj.field2)
             self.assertEqual(data['form-{0}-field3'.format(i)], obj.field3)
+            self.assertEqual(data['form-{0}-bool_field'.format(i)], obj.bool_field)
+            self.assertEqual(data['form-{0}-int_field'.format(i)], obj.int_field)
+            self.assertEqual(data['form-{0}-float_field'.format(i)], obj.float_field)
             
     def test_edit_formset_extra_1(self):
         self._log_as_editor()
@@ -344,10 +386,16 @@ class FormsetViewTestCase(BaseTestCase):
             'form-0-field1': "AZERTYUIOP",
             'form-0-field2': "<p>QWERTY/nUIOP</p>",
             'form-0-field3': "AZDD",
+            'form-0-bool_field': True,
+            'form-0-int_field': 2,
+            'form-0-float_field': 3.14,
             'form-1-id': '',
             'form-1-field1': "POIUYTREZA",
             'form-1-field2': "<p>MLKJHGFDSQ</p>",
             'form-1-field3': "QSkk",
+            'form-1-bool_field': True,
+            'form-1-int_field': 2,
+            'form-1-float_field': 3.14,
             'form-TOTAL_FORMS': 2,
             'form-INITIAL_FORMS': 1,
             'form-MAX_NUM_FORMS': 2,
@@ -366,6 +414,9 @@ class FormsetViewTestCase(BaseTestCase):
             self.assertEqual(data['form-{0}-field1'.format(i)], obj.field1)
             self.assertEqual(data['form-{0}-field2'.format(i)], obj.field2)
             self.assertEqual(data['form-{0}-field3'.format(i)], obj.field3)
+            self.assertEqual(data['form-{0}-bool_field'.format(i)], obj.bool_field)
+            self.assertEqual(data['form-{0}-int_field'.format(i)], obj.int_field)
+            self.assertEqual(data['form-{0}-float_field'.format(i)], obj.float_field)
     
     def test_edit_formset_anonymous(self):
         obj = mommy.make(TestClass)
@@ -377,6 +428,9 @@ class FormsetViewTestCase(BaseTestCase):
             'form-0-id': obj.id,
             'form-0-field1': "AZERTYUIOP",
             'form-0-field2': "<p>QWERTY/nUIOP</p>",
+            'form-0-bool_field': True,
+            'form-0-int_field': 2,
+            'form-0-float_field': 3.14,
             'form-TOTAL_FORMS': 1,
             'form-INITIAL_FORMS': 1,
             'form-MAX_NUM_FORMS': 1,
@@ -408,6 +462,9 @@ class FormsetViewTestCase(BaseTestCase):
             'form-0-id': obj.id,
             'form-0-field1': "AZERTYUIOP",
             'form-0-field2': "<p>QWERTY/nUIOP</p>",
+            'form-0-bool_field': True,
+            'form-0-int_field': 2,
+            'form-0-float_field': 3.14,
             'form-TOTAL_FORMS': 1,
             'form-INITIAL_FORMS': 1,
             'form-MAX_NUM_FORMS': 1,
@@ -435,6 +492,9 @@ class FormsetViewTestCase(BaseTestCase):
             'form-0-id': obj.id,
             'form-0-field1': "AZERTYUIOP",
             'form-0-field2': "<p>QWERTY/nUIOP</p>",
+            'form-0-bool_field': True,
+            'form-0-int_field': 2,
+            'form-0-float_field': 3.14,
             'form-TOTAL_FORMS': 1,
             'form-INITIAL_FORMS': 1,
             'form-MAX_NUM_FORMS': 1,
