@@ -3,7 +3,7 @@
 from models import TestClass
 from forms import TestClassForm
 
-from coop_cms.generic_views import EditableObjectView, ListView
+from coop_cms.generic_views import EditableObjectView, ListView, EditableFormsetView
 
 class TestClassListView(ListView):
     model = TestClass
@@ -18,4 +18,14 @@ class TestClassDetailView(EditableObjectView):
     
 class TestClassEditView(TestClassDetailView):
     edit_mode = True
+    
+class TestClassFormsetView(EditableFormsetView):
+    model = TestClass
+    edit_mode = False
+    form_class = TestClassForm
+    template_name = "coop_cms/test_app/formset.html"
+    success_view_name = 'coop_cms_testapp_formset'
+    
+class TestClassFormsetEditView(TestClassFormsetView):
+    edit_mode = True
     
\ No newline at end of file
