@@ -17,8 +17,9 @@ from django.core.exceptions import ValidationError
 # from html_field.db.models import HTMLField
 # from html_field import html_cleaner
 from coop_cms.settings import get_article_class, get_article_logo_size, get_newsletter_item_classes, get_article_logo_crop
-from coop_cms.settings import get_navtree_class, is_localized, COOP_CMS_NAVTREE_CLASS, get_article_templates
+from coop_cms.settings import get_navtree_class, is_localized, get_article_templates, COOP_CMS_NAVTREE_CLASS
 from coop_cms.settings import get_default_logo, is_requestprovider_installed
+from coop_cms.settings import get_headline_image_size, get_headline_image_crop, get_max_image_width
 from coop_cms.utils import dehtml
 from django.contrib.staticfiles import finders
 from django.core.files import File
@@ -32,6 +33,7 @@ from django.contrib.sites.models import Site
 ADMIN_THUMBS_SIZE = '60x60'
 import logging
 logger = logging.getLogger("coop_cms")
+from coop_cms.utils import RequestManager, RequestNotFound
 
 def get_object_label(content_type, object):
     """
@@ -97,6 +99,27 @@ class NavType(models.Model):
         verbose_name_plural = _(u'navigable types')
 
 
+class BaseNavTree(models.Model):
+    last_update = models.DateTimeField(auto_now=True)
+    name = models.CharField(_(u'name'), max_length=100, db_index=True, unique=True, default='default')
+    types = models.ManyToManyField('coop_cms.NavType', blank=True, related_name="%(app_label)s_%(class)s_set")
+
+    def __unicode__(self):
+        return self.name
+
+    def get_absolute_url(self):
+        return reverse('navigation_tree', args=[self.id])
+
+    def get_root_nodes(self):
+        return NavNode.objects.filter(tree=self, parent__isnull=True).order_by("ordering")
+
+    class Meta:
+        verbose_name = _(u'Navigation tree')
+        verbose_name_plural = _(u'Navigation trees')
+        abstract = True
+
+class NavTree(BaseNavTree): pass
+
 class NavNode(models.Model):
     """
     A navigation node
@@ -126,11 +149,10 @@ class NavNode(models.Model):
     def is_active_node(self):
         url = self.get_absolute_url()
         if url and is_requestprovider_installed():
-            from gadjo.requestprovider.signals import get_request
             try:
-                http_request = get_request()
+                http_request = RequestManager().get_request()
                 return http_request and http_request.path == url
-            except IndexError:
+            except RequestNotFound:
                 pass
         return False
 
@@ -275,25 +297,6 @@ class NavNode(models.Model):
                 cur_node = cur_node.parent
 
 
-class BaseNavTree(models.Model):
-    last_update = models.DateTimeField(auto_now=True)
-    name = models.CharField(_(u'name'), max_length=100, db_index=True, unique=True, default='default')
-    types = models.ManyToManyField('coop_cms.NavType', blank=True)
-
-    def __unicode__(self):
-        return self.name
-
-    def get_absolute_url(self):
-        return reverse('navigation_tree', args=[self.id])
-
-    def get_root_nodes(self):
-        return NavNode.objects.filter(tree=self, parent__isnull=True).order_by("ordering")
-
-    class Meta:
-        verbose_name = _(u'Navigation tree')
-        verbose_name_plural = _(u'Navigation trees')
-        abstract = True
-
 #content_cleaner = html_cleaner.HTMLCleaner(
 #    allow_tags=['a', 'img', 'p', 'br', 'b', 'i', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
 #        'sup', 'pre', 'ul', 'li', 'ol', 'table', 'th', 'tr', 'td', 'tbody', 'span', 'div',
@@ -383,10 +386,12 @@ class BaseArticle(BaseNavigable):
 
     DRAFT = 0
     PUBLISHED = 1
+    ARCHIVED = 2
 
     PUBLICATION_STATUS = (
         (DRAFT, _(u'Draft')),
         (PUBLISHED, _(u'Published')),
+        (ARCHIVED, _(u'Archived')),
     )
 
     def get_logo_folder(self, filename):
@@ -426,6 +431,12 @@ class BaseArticle(BaseNavigable):
     def is_draft(self):
         return self.publication == BaseArticle.DRAFT
     
+    def is_archived(self):
+        return self.publication == BaseArticle.ARCHIVED
+    
+    def is_published(self):
+        return self.publication == BaseArticle.PUBLISHED
+    
     def next_in_category(self):
         if self.category:
             try:
@@ -462,6 +473,12 @@ class BaseArticle(BaseNavigable):
         except Exception, msg:
             print "#### ERR", msg
             return logo_file
+        
+    def get_headline_image(self):
+        img_size = get_headline_image_size(self)
+        crop = get_headline_image_crop(self)
+        return self.logo_thumbnail(logo_size=img_size, logo_crop=crop).url
+        
 
     def _get_default_logo(self):
         #copy from static to media in order to use sorl thumbnail without raising a suspicious operation
@@ -615,11 +632,11 @@ class BaseArticle(BaseNavigable):
         return user.has_perm(perm)
 
     def can_view_article(self, user):
-        if self.publication != BaseArticle.PUBLISHED:
+        if not self.is_published():
             return self.can_edit_article(user)
         else:
             return True
-
+        
     def can_edit_article(self, user):
         return self._can_change(user)
 
@@ -710,7 +727,15 @@ class Image(Media):
 
     def get_absolute_url(self):
         if not self.size:
-            return self.file.url
+            max_width = get_max_image_width(self)
+            if max_width:
+                try:
+                    return sorl_thumbnail.backend.get_thumbnail(self.file.file, str(max_width), upscale=False).url
+                except Exception, msg:
+                    logger.error("Image can not resize: {0}".format(max_width))
+                    return self.file.url
+            else:
+                return self.file.url
         try:
             crop = self.size.crop or None
             return sorl_thumbnail.backend.get_thumbnail(self.file.file, self.size.size, crop=crop).url
@@ -725,15 +750,9 @@ class Image(Media):
 class Document(Media):
     def get_doc_folder(self, filename):
         if not self.is_private:
-            try:
-                doc_root = settings.DOCUMENT_FOLDER
-            except AttributeError:
-                doc_root = 'documents/public'
+            doc_root = getattr(settings, 'DOCUMENT_FOLDER', 'documents/public')
         else:
-            try:
-                doc_root = settings.PRIVATE_DOCUMENT_FOLDER
-            except AttributeError:
-                doc_root = 'documents/private'
+            doc_root = getattr(settings, 'PRIVATE_DOCUMENT_FOLDER', 'documents/private')
 
         filename = os.path.basename(filename)
         #This is required for x-sendfile
@@ -986,4 +1005,23 @@ class Fragment(models.Model):
         return super(Fragment, self).save(*args, **kwargs)
         
     def __unicode__(self):
-        return u"{0} {1} {2}".format(self.type, self.position, self.name)    
\ No newline at end of file
+        return u"{0} {1} {2}".format(self.type, self.position, self.name)
+    
+class SiteSettings(models.Model):
+    site = models.OneToOneField(Site, verbose_name=_(u'site settings'))
+    homepage_url = models.CharField(
+        max_length=256, blank=True, default="", verbose_name=_(u'homepage URL'),
+        help_text=_(u"if set, the homepage will be redirected to the given URL")
+    )
+    
+    def __unicode__(self):
+        return u"{0}".format(self.site)
+    
+    class Meta:
+        verbose_name = _(u'Sites settings')
+        verbose_name_plural = _(u'Site settings')
+        ordering = ("site__id",)
+    
+    
+    
+    
