@@ -233,10 +233,7 @@ class SafeWrapper:
 
     def __getattr__(self, field):
         value = getattr(self._wrapped, field)
-        
-        if hasattr(value, 'pk'):
-            return value
-        elif field=='logo':
+        if field=='logo':
             src = getattr(self._wrapped, 'logo_thumbnail')(False, self._logo_size, self._logo_crop)
             if src:
                 try:
@@ -248,9 +245,12 @@ class SafeWrapper:
                         logger.exception("coop_edition:SafeWrapper")
             else:
                 value = u''
+            return mark_safe(value)
         elif callable(value):
             return value()
-        return mark_safe(value)
+        elif type(value) in (unicode, str):
+            return mark_safe(value)
+        return value
 
 class FormWrapper:
 
