@@ -37,6 +37,8 @@ import logging
 logger = logging.getLogger("coop_cms")
 import itertools
 from coop_cms.settings import cms_no_homepage
+from django.views.generic import TemplateView
+from django.db.models import Q
 
 def get_article_template(article):
     template = article.template
@@ -54,9 +56,21 @@ def tree_map(request):
 
 def homepage(request):
     try:
-        article = get_article_class().objects.get(homepage_for_site__id=settings.SITE_ID, sites=settings.SITE_ID)
         if cms_no_homepage():
             raise Http404
+        
+        site = Site.objects.get_current()
+        
+        #Try site settings
+        try:
+            site_settings = models.SiteSettings.objects.get(site=site)
+            if site_settings.homepage_url:
+                return HttpResponseRedirect(site_settings.homepage_url)
+        except models.SiteSettings.DoesNotExist:
+            pass
+        
+        #Try: homepage article #Deprecated
+        article = get_article_class().objects.get(homepage_for_site=site, sites=site.id)
         return HttpResponseRedirect(article.get_absolute_url())
     except get_article_class().DoesNotExist:
         return HttpResponseRedirect(reverse('coop_cms_view_all_articles'))
@@ -123,7 +137,8 @@ def set_homepage(request, article_id):
 def view_article(request, url, extra_context=None, force_template=None):
     """view the article"""
     try:
-        article = get_article_or_404(slug=url, sites=settings.SITE_ID) #Draft & Published
+        not_archived = Q(publication=BaseArticle.ARCHIVED)
+        article = get_article_or_404(Q(slug=url) & Q(sites=settings.SITE_ID) & ~not_archived) #Draft & Published
     except Http404:
         return redirect_if_alias(path=url)
     
@@ -134,7 +149,8 @@ def view_article(request, url, extra_context=None, force_template=None):
     
     context_dict = {
         'editable': editable, 'edit_mode': False, 'article': article,
-        'draft': article.publication==models.BaseArticle.DRAFT, 'headlines': get_headlines(article),
+        'draft': article.publication==models.BaseArticle.DRAFT,
+        'headlines': get_headlines(article, editable=editable),
     }
     
     if extra_context:
@@ -1157,7 +1173,12 @@ class ArticleView(EditableObjectView):
     varname = "article"
     
     def get_object(self):
-        return get_article_or_404(slug=self.kwargs['slug'], sites=settings.SITE_ID) 
+        return get_article_or_404(slug=self.kwargs['slug'], sites=settings.SITE_ID)
+    
+    def can_access_object(self):
+        if self.object.is_archived():
+            return super(ArticleView, self).can_view_object()
+        return True
     
     def handle_object_not_found(self):
         return redirect_if_alias(path=self.kwargs['slug'])
@@ -1185,4 +1206,9 @@ class ArticleView(EditableObjectView):
         return get_article_template(self.object)
     
 class EditArticleView(ArticleView):
-    edit_mode = True
\ No newline at end of file
+    edit_mode = True
+    
+class DebugErrorCodeView(TemplateView):
+    
+    def get_template_names(self):
+        return ("{0}.html".format(self.kwargs["error_code"]),)
